handle_random_image

Function handle_random_image 

pub async fn handle_random_image(
    state: Arc<RwLock<ServerState>>,
) -> Result<Response<Full<Bytes>>>
Handle random image serving

Errors

Returns an error if no images are configured or if the image cannot be found in the cache.